@@ -36,6 +36,16 @@ test_that("bootstrap_lss works with what = seeds", {
         bootstrap_lss(lss_test, mode = "predict", newdata = dfmt_test, se_fit = TRUE),
         'formal argument "se_fit" matched by multiple actual arguments'
     )
+
+    expect_silent({
+        bs5 <- bootstrap_lss(lss_test, mode = "predict", what = "k", newdata = dfmt_test,
+                             auto_weight = TRUE)
+    })
+    expect_silent({
+        bs6 <- bootstrap_lss(lss_test, mode = "predict", what = "k", newdata = dfmt_test,
+                             auto_weight = FALSE)
+    })
+    expect_false(identical(bs5, bs6))
 })
 
 test_that("bootstrap_lss works with remove = TRUE", {
@@ -54,26 +64,26 @@ test_that("bootstrap_lss with what = k", {
 
     bs1 <- bootstrap_lss(lss_test, what = "k")
     expect_equal(class(as.vector(bs1)), "character")
-    expect_equal(ncol(bs1), 6)
+    expect_equal(ncol(bs1), 5)
     expect_equal(nrow(bs1), length(lss_test$beta))
-    expect_equal(attr(bs1, "values"), seq(50, 300, 50))
+    expect_equal(attr(bs1, "values"), seq(100, 300, 50))
 
     bs2 <- bootstrap_lss(lss_test, what = "k", by = 10)
-    expect_equal(ncol(bs2), 26)
-    expect_equal(attr(bs2, "values"), seq(50, 300, 10))
+    expect_equal(ncol(bs2), 21)
+    expect_equal(attr(bs2, "values"), seq(100, 300, 10))
 
-    bs3 <- bootstrap_lss(lss_test, what = "k", from = 100, to = 200, by = 10)
-    expect_equal(ncol(bs3), 11)
-    expect_equal(attr(bs3, "values"), seq(100, 200, 10))
+    bs3 <- bootstrap_lss(lss_test, what = "k", from = 150, to = 200, by = 10)
+    expect_equal(ncol(bs3), 6)
+    expect_equal(attr(bs3, "values"), seq(150, 200, 10))
 
     expect_error(bootstrap_lss(lss_test, what = "k", from = 0),
                  "The value of from must be between 1 and 300")
     expect_error(bootstrap_lss(lss_test, what = "k", to = 0),
                  "The value of to must be between 1 and 300")
     expect_error(bootstrap_lss(lss_test, what = "k", by = -1),
-                 "The value of by must be between 1 and 250")
+                 "The value of by must be between 1 and 300")
     expect_error(bootstrap_lss(lss_test, what = "k", by = 1000),
-                 "The value of by must be between 1 and 250")
+                 "The value of by must be between 1 and 300")
 })
 
 test_that("bootstrap_lss show messages", {
@@ -83,11 +93,11 @@ test_that("bootstrap_lss show messages", {
     )
     expect_output(
         bootstrap_lss(lss_test, "seeds", verbose = TRUE),
-        "Fitting textmodel_lss with a different hyper-parameter.*"
+        "Call terms\\(x\\) with different hyper-parameters.*"
     )
     expect_output(
         bootstrap_lss(lss_test, "k", verbose = TRUE),
-        "Fitting textmodel_lss with a different hyper-parameter.*"
+        "Call terms\\(x\\) with different hyper-parameters.*"
     )
     expect_output(
         bootstrap_lss(lss_test, "seeds", verbose = TRUE),
@@ -99,3 +109,12 @@ test_that("bootstrap_lss show messages", {
     )
 })
 
+test_that("optimize works", {
+
+    r1 <- optimize_lss(lss_test, newdata = dfmt_test, what = "k")
+    expect_identical(names(r1), c("100", "150", "200", "250", "300"))
+
+    r2 <- optimize_lss(lss_test, newdata = dfmt_test, what = "seed", remove = TRUE)
+    expect_identical(names(r2), names(lss_test$seeds_weighted))
+
+})
